// $Id: HelpPanel.java,v 1.2 2006/07/08 00:24:11 sjakob Exp $
/*
 *  HelpPanel.java - An specialized JPanel used for display
 *  of help text in HTML format.
 *  Copyright (C) 2000 Steve Jakob
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
import java.awt.*;
import javax.swing.*;
/**
 * This class is a specialized JPanel designed to display a simple help page
 * from an HTML file.
 *
 * @author   Steve Jakob
 */
public class HelpPanel extends JPanel
{
	private JEditorPane ep;

	//Constructors
	public HelpPanel()
	{
		super();
		ep = new JEditorPane();
		ep.setEditable(false);
		ep.setContentType("text/html");
		JScrollPane sp = new JScrollPane(ep);
		this.setLayout(new BorderLayout());
		this.add(sp, BorderLayout.CENTER);
	}

	public HelpPanel(java.net.URL url)
	{
		this();
		try
		{
			ep.setPage(url);
		}
		catch (java.io.IOException e)
		{}
	}

	/*
	 *  To be implemented
	 *  public HelpPanel(InputStream is) {
	 *  this();
	 *  }
	 */
	 
	//Implementors
	public Dimension getMinimumSize()
	{
		Toolkit tk = Toolkit.getDefaultToolkit();
		int minWidth = tk.getScreenSize().width / 4;
		int minHeight = tk.getScreenSize().height / 4;
		return new Dimension(minWidth, minHeight);
	}

	public Dimension getMaximumSize()
	{
		Toolkit tk = Toolkit.getDefaultToolkit();
		int maxWidth = tk.getScreenSize().width;
		int maxHeight = tk.getScreenSize().height;
		return new Dimension(maxWidth, maxHeight);
	}

	public Dimension getPreferredSize()
	{
		Toolkit tk = Toolkit.getDefaultToolkit();
		int prefWidth = tk.getScreenSize().width / 3;
		int prefHeight = tk.getScreenSize().height / 3;
		return new Dimension(prefWidth, prefHeight);
	}

}

