// $Id: StatusPane.java,v 1.2 2006/07/08 00:24:11 sjakob Exp $
/*
 *  StatusPane.java - A specialized JTExtPane for displaying
 *  status messages with different fonts and colours.
 *  Copyright (C) 2000 Steve Jakob
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
import java.awt.*;
import javax.swing.*;
import javax.swing.text.*;

/**
 * This class is a convenience class which specializes JTextPane for displaying
 * status messages with various preset styles.
 *
 * @author   Steve Jakob
 */
public class StatusPane extends JTextPane
{
	private StyledDocument doc = null;
	private Style defaultStyle, highlightStyle, successStyle, failStyle;
	// private SimpleAttributeSet defaultStyle, highlightStyle, successStyle, failStyle;
	private Highlighter hl;
	private DefaultHighlighter.DefaultHighlightPainter hlpainter;

	private static void main(String[] args)
	{
		JFrame testFrame = new JFrame();
		testFrame.getContentPane().setLayout(new BorderLayout());
		testFrame.getContentPane().add(new JLabel("StatusPane Test"), BorderLayout.NORTH);
		StatusPane testPane = new StatusPane();
		testPane.setMsg("This is a test.");
		testPane.addHighlight(0, 4);
		testFrame.getContentPane().add(testPane, BorderLayout.CENTER);
		testFrame.pack();
		testFrame.setVisible(true);
	}

	public StatusPane()
	{
		super();
		setOpaque(false);
		setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createBevelBorder(javax.swing.border.BevelBorder.LOWERED),
				BorderFactory.createEmptyBorder(1, 2, 1, 2)));
		doc = getStyledDocument();
		createStyles();
	}

	/**
	 * Creates the various styles supported by the StatusPane.
	 */
	private void createStyles()
	{
		StyleContext sc = new StyleContext();
		defaultStyle = doc.getStyle(StyleContext.DEFAULT_STYLE);
		successStyle = doc.addStyle("Success", defaultStyle);
		successStyle.addAttribute(StyleConstants.Foreground, new Color(0, 101, 0));
		failStyle = doc.addStyle("Success", defaultStyle);
		failStyle.addAttribute(StyleConstants.Foreground, Color.red);
		/*
		 *  highlightStyle = doc.addStyle("Success", defaultStyle);
		 *  highlightStyle.addAttribute(StyleConstants.Foreground, Color.blue);
		 *  highlightStyle.addAttribute(StyleConstants.Bold, new Boolean(true));
		 */
		hlpainter = new DefaultHighlighter.DefaultHighlightPainter(Color.green);
		hl = getHighlighter();
	}

	public void setMsg(String msg)
	{
		clear();
		appendString(msg, defaultStyle);
	}

	public void setSuccessMsg(String msg)
	{
		clear();
		appendString(msg, successStyle);
	}

	public void setFailureMsg(String msg)
	{
		clear();
		appendString(msg, failStyle);
	}

	public void clear()
	{
		try
		{
			doc.remove(0, doc.getLength());
			;
		}
		catch (BadLocationException e)
		{// This should never happen
			System.out.println(e);
		}
	}

	private void appendString(String msg, AttributeSet a)
	{
		try
		{
			doc.insertString(doc.getLength(), msg, a);
		}
		catch (BadLocationException e)
		{// This should never happen
			System.out.println(e);
		}
	}

	public void appendString(String msg)
	{
		appendString(msg, defaultStyle);
	}

	public void addHighlight(int start, int end)
	{
		try
		{
			hl.addHighlight(start, end, hlpainter);
		}
		catch (BadLocationException e)
		{
			System.out.println(e);
		}
	}
}

